<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Закрити (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Згорнути</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Розгорнути</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Пропустити попередження</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%1% з %Ln хвилин</numerusform>
            <numerusform>%1% з %Ln хвилин</numerusform>
            <numerusform>%1% з %Ln хвилин</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1% of %Ln word(s)</source>
        <translation>
            <numerusform>%1% з %Ln слів</numerusform>
            <numerusform>%1% з %Ln слів</numerusform>
            <numerusform>%1% з %Ln слів</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln слово</numerusform>
            <numerusform>%Ln слів</numerusform>
            <numerusform>%Ln слова</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln хвилина</numerusform>
            <numerusform>%Ln хвилини</numerusform>
            <numerusform>%Ln хвилин</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Щоденний Прогрес</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Найдовший період робочих днів</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Поточний період робочих днів</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Недоступно</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n день</numerusform>
            <numerusform>%n дні</numerusform>
            <numerusform>%n днів</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%1% of daily goal</source>
        <translation>%1% щоденного завдання</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Встановити мову</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Без назви %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Лише для читання)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>На жаль</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Не вдалось зберегти &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Зберегти файл як</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Не вдалось перезаписати &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Перейменувати файл</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Не вдалось перейменувати &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Перезавантажити файл?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Перезавантажити файл &apos;%1&apos; з диску?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Всі незбережені зміни будуть втрачені.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перевантажити</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Без назви %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Питання</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Збереження файлу як простого тексту призведе до втрати форматування. Пропустити форматування?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Файл змінено</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Файл &apos;%1&apos; був змінений в іншій програмі.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Ви хочете перевантажити файл?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перевантажити</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Пропустити</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Файл видалено</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Файл %1 видалений іншою програмою.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Ви хочете зберегти чи закрити файл?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Не вдалось відкрити архів.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Знайти:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Замінити на:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ігнорувати регістр</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Лише повні слова</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Регулярні вирази</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Пошук уверх</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Пошук вниз</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Знайти</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Замінити</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Замінити &amp;все</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Знайти</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Замінити</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Замінити %n примірник?</numerusform>
            <numerusform>Замінити %n примірники?</numerusform>
            <numerusform>Замінити %n примірників?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Запит</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>На жаль</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Фраза не знайдена.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Text</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>Відкрити документ Flat XML</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text - розширений текстовий формат</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Plain Text - Простий текст</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Всі файли</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Всі підтримувані файли</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Перевірка правопису...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Пропозицій не знайдено)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Відкрити зображення</translation>
    </message>
    <message>
        <source>Images(%1)</source>
        <translation>Зображень(%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Виберіть мову програми:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Примітка</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Перезапустіть програму, щоб зміна мови набрала чинності.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Не вдалось відкрити архів.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Загальне</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Панель інструментів</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Перевірка правопису</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Вибрати словник</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>На жаль</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Не вдалось відкрити архів.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Архів не містить придатного словника.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Запитання</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Комбінації клавіш</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Деякі комбінації клавіш збігаються. Продовжити?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Словник &quot;%1&quot; вже є. Хочете замінити його?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Щоденні завдання</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Хвилин:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Слів:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Редагування</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Завжди центрувати вертикально</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Блокувати курсор вставки</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Згладжені шрифти</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Звуки друкарської машинки</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Прямі лапки:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Подвійні</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Одинарні</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Сцени</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Роздільна лінія:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Збереження</translation>
    </message>
    <message>
        <source>Automatically save changes</source>
        <translation>Зміни зберігати автоматично</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Пам&apos;ятати позицію курсору</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Кількість слів</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Кількість сторінок</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Кількість абзаців</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Кількість символів</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Символів:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Абзаців:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Алгоритм підрахунку слів</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Скинути сьогоднішній щоденний прогрес до нуля?</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Видалити поточний словник?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Записувати мітку байта в простих текстових файлах</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Формат типово:</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Інтерфейс користувача</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Завжди відображати прокрутку</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Завжди відображати верхню панель</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Завжди відображати нижню панель</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Скинути сьогоднішнє</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Історія</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Зберігати історію</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Показувати робочі дні</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Мінімальний прогрес для зарахування дня в робочий період:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Визначати межі слова</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Ділити кількість символів на шість</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Рахувати кожну букву як слово</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Алгоритм обрахування сторінок</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Стиль</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Лише значки</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Лише текст</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Текст біля значків</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Текст під значками</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Розташування тексту:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Дії</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Перемістити уверх</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Перемістити вниз</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Додати розділювач</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Команда</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Комбінація клавіш</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Дія</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Перевіряти правопис під час введення</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ігнорувати слова у ВЕРХНЬОМУ регістрі</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Ігнорувати слова з цифрами</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Мова</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Особистий словник</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Не підтримуваний файл RTF.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Несподівано завершився файл.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Пересунути сцени вище</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Відкрити/закрити список сцен</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Показати список сцен (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Заховати список сцен (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Фільтрувати</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Пересунути сцени нижче</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Змінити розмір списку сцен</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Типово</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Керування сеансами</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>С&amp;анси</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Новий</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Дублювати</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Перейти</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Новий сеанс</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Дублювати сесію</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Перейменувати сеанс</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Запит</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Вилучити вибраний сеанс?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Назва сеансу:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>На жаль</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Така назва сеансу вже є.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Новий ...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Керування...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Скинути до типових значень</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Комбінація клавіш:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Заміна лапок...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Будь ласка, зачекайте</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Перевірка правопису</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Додати</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Пропустити</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>&amp;Пропустити все</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Замінити</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>&amp;Замінити все</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Немає в словнику:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Змінити на:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Перевірка правопису ...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Будь ласка, зачекайте</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Продовжити пошук з початку файлу?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Перевірку правопису завершено.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Символи</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Недавно використані символи</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Всі символи</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Деталі</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Назва:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Вставити</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Блоки</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Скрипти</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Без назви %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Назва:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Немає зображення</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Замостити</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>По центру</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Розтягнути</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Масштабувати</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Наблизити</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Непрозорість:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Позиція:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Заокруглені кути</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Радіус:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Розмити фон тексту</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Падаюча тінь від тексту</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Ветрикальне зміщення:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Зовнішні краї</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Вікно:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Сторінка:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Відступ першого рядка</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Перед:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Після:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Віддалити</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Редагувати тему</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Фон вікна</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Колір:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Зображення:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> пікселів</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Ліворуч</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Фон тексту</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Праворуч</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Шрифт:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>З помилкою:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Відстань між рядками</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Одинарні</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>Півтора</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Подвійні</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>ПропорційнІ</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Висота:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Відстань між абзацами</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Ширина вкладки:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Нова тема</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Теми</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Типово</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Різкі небеса</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Чарівність</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Ніжний блюз</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Стара школа</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Космічні мрії</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Шпигунські ігри</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Спокій</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Письмовий стіл</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Нова</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Дублювати</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Користувацька</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Редагувати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Імпортувати</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Експортувати</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Запитання</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Видалити тему &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Теми (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Імпортувати тему</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Експортувати тему</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Запитання</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Вилучити таймер?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Слів:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Сторінок:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Абзаців:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Символів:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Затримка</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Час</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Затримка:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Час:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Сигнал</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Для довідки:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Змінити</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Таймери не працюють</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Таймери</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Новий</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Останні</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Запитання</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Скасувати змінені таймери?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Завантаження тем</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Завантаження звуків</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Без назви</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Відкрити файл</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Про FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Простий повноекранний текстовий редактор</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Випущено під ліцензією &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Використовуються іконки з теми &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Використано відповідно до ліцензії &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Символів: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Сторінок: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Абзаців: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Слів: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Відкривання %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Без назви %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Список усіх документів</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Перейти до наступного документу</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Перейти до попереднього документу</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Перейти до першого документу</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Перейти до останнього документу</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Перейти до документу %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Завантажуються налаштування</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Резервна пам’ять недоступна для запису.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter не був закритий правильно.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Відновити відкриті файли із резервної пам’яті?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Не вдалось відкрити деякі файли.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Деякі файли були відкриті лише для читання.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; новіше резервної копії.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Замінити нову версію резервною копією?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Зберегти зміни?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Зберегти зміни у файлі &apos;%1&apos; перед закриттям?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Ваші зміни будуть втрачені, якщо ви їх не збережете.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Не вдається завантажити звук друкарської машинки.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Новий</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Відкрити...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Відкр&amp;ити заново</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Зберегти</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Зберегти &amp;як...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Перейменувати...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Зберегти вс&amp;е</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Керування сеансами</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Новий сеанс</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Друк...</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Налаштування сто&amp;рінки...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>За&amp;крити</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>В&amp;ийти</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Змінити</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Повернути</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Пов&amp;торити</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Виріза&amp;ти</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Копі&amp;ювати</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>В&amp;ставити</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Вставити без &amp;форматування</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Вибрати &amp;все</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Вибрати &amp;Сцену</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>&amp;Формат</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Заголовок</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Заголовок &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Заголовок &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Заголовок &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Заголовок &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Заголовок &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Заголовок &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Звичайний</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Напівжирний</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Курсив</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Підкреслений</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Закреслений</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Верхній &amp;індекс</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>Ни&amp;жній індекс</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>По &amp;лівому краю</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>По &amp;центру</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>По пр&amp;авому краю</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>По &amp;ширині</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Зменшити відступ</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>З&amp;більшити відступ</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Фрагмент зліва напр&amp;аво</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Фрагмент зправа нал&amp;іво</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Інструменти</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Знайти...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Знайти нас&amp;тупний</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Знайти п&amp;опередній</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>За&amp;мінити...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Прямі &amp;лапки</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Оновити &amp;документ</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Оновити розумні цитати документу</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Оновити &amp;виділене</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Оновити розумні цитати виділеного</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Перевірка правопису...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Встановити &amp;мову...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Таймери...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>С&amp;имволи...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Щоденний прогрес</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Налаштування</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Показати панель &amp;інструментів</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Показати значки мен&amp;ю</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Під&amp;свічування тексту</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Н&amp;а повний екран</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>&amp;Згорнути</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Теми...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>Пара&amp;метри...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Вимкнена</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>На одному рядку</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>На трьох рядках</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Абзац</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>На абзаці</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Мова &amp;програми...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Формат деяких файлів не підтримується програмою. Ці файли не були відкриті.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Виключено</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Один &amp;рядок</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Три рядки</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Про програму</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Про &amp;Qt</translation>
    </message>
</context>
</TS>
